@@ -4,6 +4,7 @@ Provides transparent sync/async method calling with automatic context detection.
 """
 
 from .core import smartasync
+from .smartasync_plugin import SmartasyncPlugin
 
-__version__ = "0.1.0"
-__all__ = ["smartasync"]
+__version__ = "0.3.0"
+__all__ = ["smartasync", "SmartasyncPlugin"]
